@@ -1,7 +1,7 @@
 #include <cassert>
 #include <iostream>
 
-#include <pqxx/all.h>
+#include <pqxx/pqxx>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -23,23 +23,21 @@ int main()
     transaction<> T(C, "test1");
 
     // Perform a query on the database, storing result tuples in R.
-    result R( T.Exec("SELECT * FROM pg_tables") );
+    result R( T.exec("SELECT * FROM pg_tables") );
 
     // Process each successive result tuple
     for (result::const_iterator c = R.begin(); c != R.end(); ++c)
     {
-      // Read value of column 0 into a string N
-      string N;
-      c[0].to(N);
-
-      // Dump tuple number and column 0 value to cout
-      cout << '\t' << ToString(c.num()) << '\t' << N << endl;
+      // Dump tuple number and column 0 value to cout.  Read the value using
+      // as(), which converts the field to the same type as the default value 
+      // you give it (or returns the default value if the field is null).
+      cout << '\t' << ToString(c.num()) << '\t' << c[0].as(string()) << endl;
     }
 
     // Tell the transaction that it has been successful.  This is not really
     // necessary here, since we didn't make any modifications to the database
     // so there are no changes to commit.
-    T.Commit();
+    T.commit();
   }
   catch (const exception &e)
   {
