@@ -1,9 +1,9 @@
 #include <iostream>
 
-#include <pqxx/connection.h>
-#include <pqxx/nontransaction.h>
-#include <pqxx/transactor.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/nontransaction>
+#include <pqxx/transactor>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -27,7 +27,7 @@ public:
 
   void operator()(argument_type &T)
   {
-    m_Result = T.Exec("SELECT * FROM pg_tables");
+    m_Result = T.exec("SELECT * FROM pg_tables");
   }
 
   void OnCommit()
@@ -50,9 +50,9 @@ int main(int, char *argv[])
     connection C(argv[1]);
 
     // See if Deactivate() behaves...
-    C.Deactivate();
+    C.deactivate();
 
-    C.Perform(ReadTables());
+    C.perform(ReadTables());
   }
   catch (const sql_error &e)
   {
