@@ -3,10 +3,10 @@
 #include <stdexcept>
 #include <vector>
 
-#include <pqxx/connection.h>
-#include <pqxx/tablereader.h>
-#include <pqxx/tablewriter.h>
-#include <pqxx/transaction.h>
+#include <pqxx/connection>
+#include <pqxx/tablereader>
+#include <pqxx/tablewriter>
+#include <pqxx/transaction>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -55,7 +55,7 @@ void PrepareContents()
 }
 
 
-void FillTable(Transaction &T, string TableName)
+void FillTable(transaction_base &T, string TableName)
 {
   tablewriter W(T, TableName);
   W.reserve(Contents.size());
@@ -66,9 +66,9 @@ void FillTable(Transaction &T, string TableName)
 }
 
 
-void CheckTable(Transaction &T, string TableName)
+void CheckTable(transaction_base &T, string TableName)
 {
-  result Count = T.Exec("SELECT COUNT(*) FROM " + TableName);
+  result Count = T.exec("SELECT COUNT(*) FROM " + TableName);
   size_t Rows = 0;
 
   if (!Count[0][0].to(Rows)) throw runtime_error("NULL row count!");
@@ -99,16 +99,16 @@ int main(int argc, char *argv[])
     string TableName = "testtable";
     if (argc > 2) TableName = argv[2];
 
-    Transaction T(C, "test28");
+    transaction<> T(C, "test28");
 
     // Create table.  If the table already existed, better to fail now.
-    T.Exec("CREATE TABLE " + TableName + "(content VARCHAR)");
+    T.exec("CREATE TABLE " + TableName + "(content VARCHAR)");
 
     FillTable(T, TableName);
     CheckTable(T, TableName);
 
-    T.Exec("DROP TABLE " + TableName);
-    T.Commit();
+    T.exec("DROP TABLE " + TableName);
+    T.commit();
   }
   catch (const sql_error &e)
   {
